"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var http_client_1 = require("../../lib/http/http-client");
var sl_routes_1 = require("../http/sl-routes");
var messages_formatter_1 = require("../messages-formatter");
var FootprintsServiceProxy = /** @class */ (function () {
    function FootprintsServiceProxy(cfg, logger) {
        this.initHttpConfig(cfg);
        this.logger = logger;
        this.httpClient = new http_client_1.HttpClient(this.httpConfig, logger);
    }
    FootprintsServiceProxy.prototype.submitFootprints = function (packetToSend, callback) {
        if (!packetToSend) {
            this.logger.info("Submit footprints - got null or empty packet. Skip submitting.");
            return;
        }
        var hitFiles = this.getHitFiles(packetToSend);
        this.logger.debug("Submitting footprints, tests: %s", JSON.stringify(packetToSend.tests));
        this.logger.debug("Submitting footprints, files: %s", hitFiles);
        var url = sl_routes_1.SLRoutes.footprintsV5();
        this.httpClient.post(packetToSend, url, callback);
    };
    FootprintsServiceProxy.prototype.initHttpConfig = function (cfg) {
        var config = {
            token: cfg.token.value,
            server: cfg.server.value,
            proxy: cfg.proxy.value,
            compressRequests: cfg.gzip.hasValue ? cfg.gzip.value : true
        };
        this.httpConfig = config;
    };
    FootprintsServiceProxy.prototype.getHitFiles = function (packetToSend) {
        if (!this.logger.debug()) {
            return;
        }
        var formatter = new messages_formatter_1.MessagesFormatter();
        if (packetToSend && packetToSend.apps && packetToSend.apps[0] && packetToSend.apps[0].files) {
            packetToSend.apps[0].files.forEach(function (file) {
                formatter.addContent(file.path);
            });
        }
        return formatter.content;
    };
    return FootprintsServiceProxy;
}());
exports.FootprintsServiceProxy = FootprintsServiceProxy;
//# sourceMappingURL=footprints-service-proxy.js.map